@@ -1,7 +1,7 @@
 ;;; -*- mode: Emacs-Lisp; coding: iso-2022-7bit; -*-
 ;;; tramp-cache.el --- file information caching for Tramp
 
-;; Copyright (C) 2000, 2005, 2006 by Free Software Foundation, Inc.
+;; Copyright (C) 2000, 2005, 2006, 2007 by Free Software Foundation, Inc.
 
 ;; Author: Daniel Pittman <daniel@inanna.danann.net>
 ;;         Michael Albinus <michael.albinus@gmx.de>
@@ -45,7 +45,7 @@
 ;;  `file-attributes'.
 ;;
 ;; - The key is a process.  This are temporary properties related to
-;;   an open connection.  Examples: "scripts" keeps to shell script
+;;   an open connection.  Examples: "scripts" keeps shell script
 ;;   definitions already sent to the remote shell, "last-cmd-time" is
 ;;   the time stamp a command has been sent to the remote process.
 
@@ -130,23 +130,6 @@ Remove also properties of all files in subdirectories."
 	  (remhash key tramp-cache-data)))
      tramp-cache-data)))
 
-(defmacro with-file-property (vec file property &rest body)
-  "Check in Tramp cache for PROPERTY, otherwise execute BODY and set cache.
-FILE must be a local file name on a connection identified via VEC."
-  `(if (file-name-absolute-p ,file)
-      (let ((value (tramp-get-file-property ,vec ,file ,property 'undef)))
-	(when (eq value 'undef)
-	  ;; We cannot pass @body as parameter to
-	  ;; `tramp-set-file-property' because it mangles our
-	  ;; debug messages.
-	  (setq value (progn ,@body))
-	  (tramp-set-file-property ,vec ,file ,property value))
-	value)
-     ,@body))
-
-(put 'with-file-property 'lisp-indent-function 3)
-(put 'with-file-property 'edebug-form-spec t)
-
 (defun tramp-cache-print (table)
   "Prints hash table TABLE."
   (when (hash-table-p table)
@@ -167,9 +150,9 @@ FILE must be a local file name on a connection identified via VEC."
        table)
       result)))
 
-;; Reverting a buffer should also flush file properties.  They could
-;; have been changed outside Tramp.
-(defun tramp-cache-before-revert-function ()
+;; Reverting or killing a buffer should also flush file properties.
+;; They could have been changed outside Tramp.
+(defun tramp-flush-file-function ()
   "Flush all Tramp cache properties from buffer-file-name."
   (let ((bfn (buffer-file-name)))
     (when (and (stringp bfn) (tramp-tramp-file-p bfn))
@@ -177,11 +160,14 @@ FILE must be a local file name on a connection identified via VEC."
 	     (localname (tramp-file-name-localname v)))
 	(tramp-flush-file-property v localname)))))
 
-(add-hook 'before-revert-hook 'tramp-cache-before-revert-function)
+(add-hook 'before-revert-hook 'tramp-flush-file-function)
+(add-hook 'kill-buffer-hook 'tramp-flush-file-function)
 (add-hook 'tramp-cache-unload-hook
 	  '(lambda ()
 	     (remove-hook 'before-revert-hook
-			  'tramp-cache-before-revert-function)))
+			  'tramp-flush-file-function)
+	     (remove-hook 'kill-buffer-hook
+			  'tramp-flush-file-function)))
 
 ;;; -- Properties --
 
@@ -235,20 +221,6 @@ function is intended to run also as process sentinel."
 ;  (tramp-message key 7 "%s" event)
   (remhash key tramp-cache-data))
 
-(defmacro with-connection-property (key property &rest body)
-  "Checks in Tramp for property PROPERTY, otherwise executes BODY and set."
-  `(let ((value (tramp-get-connection-property ,key ,property 'undef)))
-    (when (eq value 'undef)
-      ;; We cannot pass ,@body as parameter to
-      ;; `tramp-set-connection-property' because it mangles our debug
-      ;; messages.
-      (setq value (progn ,@body))
-      (tramp-set-connection-property ,key ,property value))
-    value))
-
-(put 'with-connection-property 'lisp-indent-function 2)
-(put 'with-connection-property 'edebug-form-spec t)
-
 (defun tramp-dump-connection-properties ()
 "Writes persistent connection properties into file
 `tramp-persistency-file-name'."
