@@ -380,7 +380,7 @@ KEEP-DATE is not handled in case NEWNAME resides on an SMB server."
   "Like `file-local-copy' for tramp files."
   (with-parsed-tramp-file-name filename nil
     (let ((file (tramp-smb-get-localname localname t))
-	  (tmpfil (tramp-make-temp-file)))
+	  (tmpfil (tramp-make-temp-file filename)))
       (unless (file-exists-p filename)
 	(tramp-error
 	 v 'file-error
@@ -444,6 +444,14 @@ KEEP-DATE is not handled in case NEWNAME resides on an SMB server."
 		      (tramp-smb-get-file-entries
 		       (file-name-directory filename)))))
 
+	(when wildcard
+	  (string-match "\\." base)
+	  (setq base (replace-match "\\\\." nil nil base))
+	  (string-match "\\*" base)
+	  (setq base (replace-match ".*" nil nil base))
+	  (string-match "\\?" base)
+	  (setq base (replace-match ".?" nil nil base)))
+
 	;; Filter entries.
 	(setq entries
 	      (delq
@@ -453,7 +461,7 @@ KEEP-DATE is not handled in case NEWNAME resides on an SMB server."
 		   (mapcar
 		    (lambda (x)
 		      (when (string-match
-			     (format "^%s" (regexp-quote base)) (nth 0 x))
+			     (format "^%s" base) (nth 0 x))
 			x))
 		    entries)
 		 ;; We just need the only and only entry FILENAME.
@@ -590,7 +598,7 @@ Catches errors for shares like \"C$/\", which are common in Microsoft Windows."
 	  (curbuf (current-buffer))
 	  tmpfil)
       ;; Write region into a tmp file.
-      (setq tmpfil (tramp-make-temp-file))
+      (setq tmpfil (tramp-make-temp-file filename))
       ;; We say `no-message' here because we don't want the visited file
       ;; modtime data to be clobbered from the temp file.  We call
       ;; `set-visited-file-modtime' ourselves later on.
