@@ -1,8 +1,8 @@
 ;;; -*- coding: iso-2022-7bit; -*-
 ;;; tramp-util.el --- Misc utility functions to use with Tramp
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005,
-;;   2006 Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006,
+;;   2007 Free Software Foundation, Inc.
 
 ;; Author: Kai Gro,A_(Bjohann <kai.grossjohann@gmx.net>
 ;;         Michael Albinus <michael.albinus@gmx.de>
@@ -446,8 +446,17 @@ Works only for relative file names and Tramp file names."
        'tramp-util-unload-hook
        '(lambda () (ad-unadvise ,x)))))
 
- '(ediff-exec-process
+ '(browse-url-default-windows-browser
+   browse-url-default-macosx-browser browse-url-netscape
+   browse-url-mozilla browse-url-firefox browse-url-galeon
+   browse-url-epiphany browse-url-gnome-moz browse-url-mosaic
+   browse-url-grail browse-url-cci browse-url-iximosaic
+   browse-url-w3-gnudoit browse-url-lynx-xterm
+   browse-url-lynx-emacs browse-url-mmm browse-url-generic
+   browse-url-kde
+   ediff-exec-process
    gnus-1
+   ispell-start-process
    jka-compr-call-process jka-compr-partial-uncompress))
 
 (provide 'tramp-util)
